<?php
/**
 * Counter Customizer options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */


// Add counter enable section
$wp_customize->add_section( 'kids_education_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','kids-education-pro' ),
	'description'       => esc_html__( 'Counter section options.', 'kids-education-pro' ),
	'panel'             => 'kids_education_pro_sections_panel'
) );

// Add counter enable setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_enable]', array(
	'default'           => $options['counter_enable'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[counter_enable]', array(
	'label'             => esc_html__( 'Enable on', 'kids-education-pro' ),
	'section'           => 'kids_education_pro_counter_section',
	'type'              => 'select',
	'choices'           => kids_education_pro_enable_disable_options()
) );

// Add features content layout setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_section_layout]', array(
	'default'           => $options['counter_section_layout'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[counter_section_layout]', array(
	'label'           	=> esc_html__( 'Select Layout', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_counter_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'kids_education_pro_is_counter_active',
	'choices'         	=> array(
		'three-columns'	=> esc_html__( 'Three Columns', 'kids-education-pro'),
		'four-columns'	=> esc_html__( 'Four Columns','kids-education-pro'),
	)
) );

// Add counter content type setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_content_type]', array(
	'default'           => $options['counter_content_type'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[counter_content_type]', array(
	'label'           => esc_html__( 'Content Type', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_counter_section',
	'type'            => 'select',
	'active_callback' => 'kids_education_pro_is_counter_active',
	'choices'         => array(
		'demo'   	  => esc_html__( 'Demo', 'kids-education-pro' ),
		'custom' 	  => esc_html__( 'Custom Content', 'kids-education-pro' )
	)
) );

// Show counter section title setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'           => $options['counter_section_title'],
	'transport'         => 'postMessage'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[counter_section_title]', array(
	'label'           => esc_html__( 'Section Title', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_counter_section',
	'active_callback' => 'kids_education_pro_is_counter_content_demo_inactive',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[counter_section_title]', array(
		'selector'            => '#counter h2.entry-title',
		'render_callback'     => 'kids_education_pro_customize_partial_counter_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Show counter section description setting and control
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_section_description]', array(
	'sanitize_callback' => 'esc_textarea',
	'default'           => $options['counter_section_description'],
	'transport'         => 'postMessage'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[counter_section_description]', array(
	'label'           => esc_html__( 'Section Description', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_counter_section',
	'active_callback' => 'kids_education_pro_is_counter_content_demo_inactive',
	'type'            => 'textarea'
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'kids_education_pro_theme_options[counter_section_description]', array(
		'selector'            => '#counter p.sub-title',
		'render_callback'     => 'kids_education_pro_customize_partial_counter_subtitle',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add features count setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_count]', array(
	'default'           => $options['counter_count'],
	'validate_callback' => 'kids_education_pro_validate_no_of_counter',
	'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[counter_count]', array(
	'label'           => esc_html__( 'Number of Achievements.', 'kids-education-pro' ),
	'description'     => esc_html__( 'Notice: Please refresh after the number of achievement is modified to view changes.', 'kids-education-pro' ),
	'section'         => 'kids_education_pro_counter_section',
	'type'            => 'number',
	'active_callback' => 'kids_education_pro_is_counter_content_demo_inactive',
	'input_attrs'     => array(
		'max' 		  => 9,
		'min' 		  => 1
	)
) );

for ( $i=1; $i <= $options['counter_count']; $i++ ) {
	// Show counter icon setting and control
	$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_icon_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[counter_icon_'.$i.']', array(
		'description'     => sprintf( esc_html__( 'Example fa-cloud-upload see more at %1$s Font awesome %2$s.', 'kids-education-pro' ), '<a target="_blank" href="'.esc_url( 'http://fontawesome.io/icons/' ).'">', '</a>' ),
		'section'         => 'kids_education_pro_counter_section',
		'active_callback' => 'kids_education_pro_is_counter_content_demo_inactive',
		'input_attrs'     => array( 'placeholder' => esc_attr__( 'fa-user','kids-education-pro' ), )
	) );

	// Show counter name setting and control
	$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_name_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[counter_name_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Name #%s', 'kids-education-pro' ), $i ),
		'section'         => 'kids_education_pro_counter_section',
		'active_callback' => 'kids_education_pro_is_counter_content_demo_inactive',
	) );

	// Show counter count setting and control
	$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_count_'.$i.']', array(
		'sanitize_callback' => 'kids_education_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'kids_education_pro_theme_options[counter_count_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Count #%s', 'kids-education-pro' ), $i ),
		'section'         => 'kids_education_pro_counter_section',
		'active_callback' => 'kids_education_pro_is_counter_content_demo_inactive',
		'type'			  => 'number',
		'input_attrs'	  => array(
			'min' 		  => 0
		)
	) );

	// Counter hr setting and control
	$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_content_custom_hr'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new kids_education_pro_Customize_Horizontal_Line( $wp_customize, 'kids_education_pro_theme_options[counter_content_custom_hr'.$i.']',
		array(
			'section'         => 'kids_education_pro_counter_section',
			'active_callback' => 'kids_education_pro_is_counter_content_demo_inactive',
			'type'			  => 'hr'
	) ) );
}

// Add background property setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_background_property]', array(
	'default'           => $options['counter_background_property'],
	'sanitize_callback' => 'kids_education_pro_sanitize_select'
) );

$wp_customize->add_control( 'kids_education_pro_theme_options[counter_background_property]', array(
	'label'           	=> esc_html__( 'Select background property', 'kids-education-pro' ),
	'section'         	=> 'kids_education_pro_counter_section',
	'active_callback' 	=> 'kids_education_pro_is_counter_content_demo_inactive',
	'type'				=> 'select',
	'choices'			=> array(
		'background_image' => esc_html__( 'Background Image', 'kids-education-pro' ),
		'background_color' => esc_html__( 'Background Color', 'kids-education-pro' ), 
	)
) );

// Add background image setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_background_image]', array(
	'default'           => $options['counter_background_image'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kids_education_pro_theme_options[counter_background_image]',
    array(
		'label'           => esc_html__( 'Upload a background image', 'kids-education-pro' ),
		'description'     => esc_html__( 'Recommended background image size is 1920x420 px', 'kids-education-pro' ),
		'section'         => 'kids_education_pro_counter_section',
		'active_callback' => 'kids_education_pro_is_counter_background_property_image',
   )
));

// Add background color setting and control.
$wp_customize->add_setting( 'kids_education_pro_theme_options[counter_background_color]', array(
	'default'           => $options['counter_background_color'],
	'sanitize_callback' => 'sanitize_hex_color'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'kids_education_pro_theme_options[counter_background_color]', array(
	'label'        => esc_html__( 'Background Color', 'kids-education-pro' ),
	'section'    => 'kids_education_pro_counter_section',
	'active_callback' => 'kids_education_pro_is_counter_background_property_color',
) ) );