<?php
/**
 * recent_post section
 *
 * This is the template for the content of recent_post section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_recent_post_section' ) ) :
  /**
   * Add recent_post section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_recent_post_section() {

    // Check if recent_post is enabled on frontpage
    $enable_recent_post = apply_filters( 'kids_education_pro_section_status', true, 'enable_recent_post' );

    if ( true !== $enable_recent_post ) {
      return false;
    }

    // Get recent_post section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_recent_post_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render recent_post section now.
    kids_education_pro_render_recent_post_section( $section_details );
  }
endif;

$options = kids_education_pro_get_theme_options();
if ( $options['site_design'] == 'fourth-design' ) {
    add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_recent_post_section', 30 );
}



if ( ! function_exists( 'kids_education_pro_get_recent_post_section_details' ) ) :
  /**
   * recent_post section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input recent_post section details.
   */
   function kids_education_pro_get_recent_post_section_details( $input ) {
      $options = kids_education_pro_get_theme_options(); 

      // Main recent_post type
      $recent_post_content_type    = $options['recent_post_type'];
      $no_of_posts = $options['recent_post_no_of_posts'];

      $content = array();

         switch ( $recent_post_content_type ) {

            case 'category':
                $categories = array();
                $categories = !empty( $options['recent_post_category_type'] ) ? $options['recent_post_category_type'] : array();
                $category = array_filter( $categories );
                
                if ( ! empty( $category ) ) {
                
                    $args = array(
                        'category__in'      => $category,
                        'posts_per_page'    => $no_of_posts,
                    );
                }
            break;

            case 'post':
                $post_list = array();
                for ( $i = 1; $i <= $no_of_posts ; $i++ ) { 
                    $post_id    = ! empty ( $options['recent_post_post_id_' . $i] ) ? absint( $options['recent_post_post_id_' . $i] ) : '';
                    $post_list  = array_merge( $post_list, array( $post_id ) );
                }

                if ( ! empty( $post_list ) ) {
                
                    $args = array(
                        'post__in'           => $post_list,
                        'posts_per_page'    => $no_of_posts,
                    );
                }
            break;

            case 'page':
                $page_list = array();
                for ( $i = 1; $i <= $no_of_posts ; $i++ ) { 
                    $page_id    = ! empty ( $options['recent_post_page_id_' . $i] ) ? absint( $options['recent_post_page_id_' . $i] ) : '';
                    $page_list  = array_merge( $page_list, array( $page_id ) );
                }

                if ( ! empty( $page_list ) ) {
                
                    $args = array(
                        'post_type'          => 'page',
                        'post__in'           => $page_list,
                        'posts_per_page'     => $no_of_posts,
                    );
                }
            break;

            default:
            break;          
         }
            
        if( ! empty ( $args ) ) :
            $custom_posts = get_posts( $args );
    
            $i = 0;
            foreach ( $custom_posts as $key => $custom_post ) {
                $img_array = null;

                if ( has_post_thumbnail( $custom_post->ID ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'post-thumbnail' );
                } else {
                        $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-recent_post-image-1350x550.jpg' );
                }

                if ( isset( $img_array ) ) {
                    $content[$i]['img_array'] = $img_array;
                }

                $year  = get_the_time('Y', $custom_post->ID  );
                $month = get_the_time('m', $custom_post->ID  );
                $day   = get_the_time('d', $custom_post->ID  );
                $content[$i]['date']      = get_the_date( '', $custom_post->ID );
                $content[$i]['date_link'] = get_day_link( $year, $month, $day );
                $content[$i]['gmt_time']  = $custom_post->post_date_gmt;
                $content[$i]['url']      = get_permalink( $custom_post->ID );
                $content[$i]['title']    = get_the_title( $custom_post->ID );
                $content[$i]['content']  = kids_education_pro_trim_content( $options['recent_post_excerpt'], $custom_post );
                $content[$i]['id']       = $custom_post->ID ;
            $i++;
            }
        endif;
        

         if ( ! empty( $content ) ) {
            $input = $content;
         }
    return $input; 
}
endif;
// recent_post section content details.
add_filter( 'kids_education_pro_filter_recent_post_section_details', 'kids_education_pro_get_recent_post_section_details' );


if ( ! function_exists( 'kids_education_pro_render_recent_post_section' ) ) :
  /**
   * Start recent_post section
   *
   * @return string recent_post content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_recent_post_section( $content_details = array() ) {
    $options = kids_education_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="recent-posts">
            <div class="container">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['recent_post_title'] ) ?></h2>
                </div><!-- .section-header -->

                <div class="col-2 clear">
                  <?php foreach ($content_details as $content_detail): ?>
                    <article>
                        <div class="featured-post-item">
                            <div class="featured-image">
                                <img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>">

                              <span class="posted-on">
                                <span class="screen-reader-text"><?php esc_html_e( 'Posted on', 'kids-education-pro' ); ?></span>
                                <a href="<?php echo esc_url($content_detail['date_link'] );?>">
                                    <time class="entry-date published" datetime="<?php echo esc_attr( $content_detail['gmt_time'] );?>"><?php echo esc_html( $content_detail['date'] );?></time>
                                    <time class="updated" datetime="<?php echo esc_attr( $content_detail['gmt_time'] );?>"><?php echo esc_html( $content_detail['date'] ); ?></time>
                                </a>
                              </span><!-- .posted-on -->
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                              <ul class="post-categories">
                                  <?php the_category( '', '', $content_detail['id'] ) ?>
                              </ul><!-- .cat-links -->

                              <header class="entry-header">
                                  <h2 class="entry-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h2>
                              </header>   

                              <div class="entry-content">
                                  <p><?php echo esc_html( $content_detail['content'] ); ?></p>
                              </div><!-- .entry-content -->
                        </div><!-- .featured-post-item -->
                    </article>
                  <?php endforeach; ?>
                </div><!-- .col-2 -->
            </div><!-- .container -->
        </div>
        <?php if ( !empty( $options['ads_image'] ) ): ?>
            <div id="advertisement-section">
              <div class="container">
                  <a href="<?php echo esc_url( $options['ads_url'] ) ?>"><img src="<?php echo esc_url( $options['ads_image'] ) ?>"></a>
              </div><!-- .container -->
          </div> 
        <?php endif ?>
       
<?php 
    }
endif;